#!/bin/bash

# Easy RAG Service 环境设置脚本

echo "=== Easy RAG Service 环境设置 ==="

# 检查 Python 版本
echo "检查 Python 版本..."
python_version=$(python3 --version 2>&1 | cut -d" " -f2 | cut -d"." -f1,2)
required_version="3.8"

if [ "$(printf '%s\n' "$required_version" "$python_version" | sort -V | head -n1)" = "$required_version" ]; then
    echo "✓ Python 版本符合要求: $python_version"
else
    echo "✗ Python 版本过低: $python_version (需要 >= $required_version)"
    echo "请使用 pyenv 安装合适的 Python 版本:"
    echo "  pyenv install 3.13.0  # 推荐最新稳定版"
    echo "  pyenv install 3.12.0  # 或其他 3.8+ 版本"  
    echo "  pyenv local 3.13.0    # 使用你安装的版本"
    exit 1
fi

# 创建虚拟环境
if [ ! -d "venv" ]; then
    echo "创建虚拟环境..."
    python3 -m venv venv
    echo "✓ 虚拟环境创建完成"
else
    echo "✓ 虚拟环境已存在"
fi

# 激活虚拟环境
echo "激活虚拟环境..."
source venv/bin/activate

# 升级 pip
echo "升级 pip..."
pip install --upgrade pip

# 安装依赖
echo "安装项目依赖..."
pip install -r requirements.txt

# 创建环境变量文件
if [ ! -f ".env" ]; then
    echo "创建环境变量文件..."
    cp .env.example .env
    echo "✓ 已创建 .env 文件，请编辑设置你的 API 密钥"
else
    echo "✓ .env 文件已存在"
fi

# 创建必要目录
echo "创建必要目录..."
mkdir -p uploads
mkdir -p chroma_db

echo ""
echo "=== 设置完成 ==="
echo "请完成以下步骤:"
echo "1. 编辑 .env 文件，设置你的 OpenAI API 密钥"
echo "2. 激活虚拟环境: source venv/bin/activate"
echo "3. 启动服务: ./start.sh 或 python main.py"
echo ""
echo "快速启动:"
echo "  source venv/bin/activate && python main.py"
