#!/bin/bash

# Easy RAG Service 启动脚本

echo "=== Easy RAG Service 启动脚本 ==="

# 检查是否在虚拟环境中
if [[ "$VIRTUAL_ENV" == "" ]]; then
    echo "警告: 您当前不在虚拟环境中"
    echo "建议先激活虚拟环境: source venv/bin/activate"
    read -p "是否继续? (y/N): " -n 1 -r
    echo
    if [[ ! $REPLY =~ ^[Yy]$ ]]; then
        exit 1
    fi
fi

# 检查 .env 文件
if [ ! -f ".env" ]; then
    echo "错误: .env 文件不存在"
    echo "请复制 .env.example 到 .env 并配置必要的环境变量"
    exit 1
fi

# 检查依赖
echo "检查 Python 依赖..."
if ! python -c "import fastapi" 2>/dev/null; then
    echo "错误: FastAPI 未安装"
    echo "请运行: pip install -r requirements.txt"
    exit 1
fi

# 创建必要的目录
echo "创建必要的目录..."
mkdir -p uploads
mkdir -p chroma_db

# 启动服务
echo "启动 Easy RAG Service..."
echo "服务将在 http://localhost:8000 运行"
echo "API 文档: http://localhost:8000/docs"
echo "按 Ctrl+C 停止服务"

python main.py
